pub struct PcoData { /* private fields */ }Expand description
Encoding-specific data for a PcoArray.
Implementations
Sourceimpl PcoData
impl PcoData
Sourcepub fn validate(
&self,
dtype: &DType,
len: usize,
validity: &Validity,
) -> VortexResult<()>
pub fn validate( &self, dtype: &DType, len: usize, validity: &Validity, ) -> VortexResult<()>
Validate dtype, validity, slice, and Pco component invariants.
Sourcepub fn new(
chunk_metas: Vec<ByteBuffer>,
pages: Vec<ByteBuffer>,
ptype: PType,
metadata: PcoMetadata,
len: usize,
) -> Self
pub fn new( chunk_metas: Vec<ByteBuffer>, pages: Vec<ByteBuffer>, ptype: PType, metadata: PcoMetadata, len: usize, ) -> Self
Construct unsliced Pco data from chunk metadata, pages, and serialized metadata.
Sourcepub fn from_primitive(
parray: ArrayView<'_, Primitive>,
level: usize,
values_per_page: usize,
ctx: &mut ExecutionCtx,
) -> VortexResult<Self>
pub fn from_primitive( parray: ArrayView<'_, Primitive>, level: usize, values_per_page: usize, ctx: &mut ExecutionCtx, ) -> VortexResult<Self>
Compress a primitive array into Pco data.
Sourcepub fn from_array(
array: ArrayRef,
level: usize,
nums_per_page: usize,
ctx: &mut ExecutionCtx,
) -> VortexResult<Self>
pub fn from_array( array: ArrayRef, level: usize, nums_per_page: usize, ctx: &mut ExecutionCtx, ) -> VortexResult<Self>
Downcast and compress an array into Pco data.
Errors
Returns an error if the input is not a primitive array or compression fails.
Sourcepub fn decompress(
&self,
unsliced_validity: &Validity,
ctx: &mut ExecutionCtx,
) -> VortexResult<PrimitiveArray>
pub fn decompress( &self, unsliced_validity: &Validity, ctx: &mut ExecutionCtx, ) -> VortexResult<PrimitiveArray>
Decompress this Pco data into a primitive array.